@@ -23,4 +23,4 @@ def hello():
     return "Hello " + obj.get_suffix()
 
 if __name__ == "__main__":
-    app.run()
\ No newline at end of file
+    app.run(debug=True)
\ No newline at end of file
